<template>
    <div class="tree-side">
        <!-- tab选项 -->
        <el-tabs v-model="activeTab" @tab-click="handleClick">
            <template v-if="tabList.length">
                <el-tab-pane
                    :label="item"
                    :name="index + ''"
                    v-for="(item, index) in tabList"
                    :key="index"
                ></el-tab-pane>
            </template>
            <!-- 筛选框 -->
            <el-input
                prefix-icon="el-icon-search"
                placeholder="请输入"
                v-model="filterText"
            >
            </el-input>
            <!-- 树形数据 -->
            <el-tree
                class="filter-tree tree-content"
                :data="treeData"
                :expand-on-click-node="false"
                :props="defaultProps"
                default-expand-all
                :filter-node-method="filterNode"
                :highlight-current="true"
                ref="tree"
                @current-change="currentChange"
                node-key="id"
            >
                <template #default="{node, data}">
                    <template v-if="data.children">
                        <div class="tree-item">
                            <i class="el-icon-folder"></i>
                            <span class="custom-node-text">{{
                                data[defaultProps.label]
                            }}</span>
                        </div>
                    </template>
                    <template v-else>
                        <div class="tree-item">
                            <i class="el-icon-tickets"></i>
                            <span class="custom-node-text">{{
                                data[defaultProps.label]
                            }}</span>
                        </div>
                    </template>
                </template>
            </el-tree>
        </el-tabs>
    </div>
</template>

<script>
export default {
    name: 'treeSide', // 侧边树
    props: {
        // tab数据
        tabList: {
            type: Array,
            default: () => {
                return []
            },
        },
        // 树形结构data数据
        treeData: {
            type: Array,
            default: () => {
                return []
            },
        },
        // 树形配置项
        defaultProps: {
            type: Object,
            default: () => {
                return {
                    label: 'label',
                    children: 'children',
                }
            },
        },
        activeName: {
            type: String,
            default: '0',
        },
    },
    data() {
        return {
            filterText: '', // 筛选输入值
            activeTab: '0', // tab激活项
            currentNode: {},
        }
    },
    watch: {
        filterText(val) {
            this.$refs.tree.filter(val)
            this.$emit('filterChange', val)
        },
    },
    created() {},
    mounted() {
        if (this.activeName) {
            this.activeTab = this.activeName
        }
    },
    methods: {
        // tab页切换事件
        handleClick(tab, event) {
            this.$emit('tabChange', tab, event)
        },
        // 树形筛选
        filterNode(value, data) {
            if (!value) return true
            return data[this.defaultProps.label].indexOf(value) !== -1
        },
        // 当前选中节点变化时触发的事件
        currentChange(value, data) {
            if (
                this.currentNode[this.defaultProps.label] ==
                value[this.defaultProps.label]
            ) {
                this.$refs.tree.setCurrentKey(null)
                this.currentNode = {}
                this.$emit('currentChange', null,data,this.activeTab)
            } else {
                this.currentNode = value
                this.$emit('currentChange', value, data,this.activeTab)
            }
        },
    },
}
</script>

<style scoped lang="scss">
.tree-side {
    width: 300px;
    height: calc(100% - 16px);
    padding: 10px 16px;
    background: #ffffff;
    box-sizing: border-box;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;
    overflow: hidden;
}

.tree-content {
    margin-top: 10px;
    border: none;
}

.tree-item {
    // height: 46px;
}

::v-deep .el-tabs__active-bar {
    // width: 20px !important;
    // left: 20px;
    background-color: #3399ff;
}

::v-deep .el-tabs__item {
    font-weight: 700;
    color: #7a8899;
    // padding: 0 16px !important;
}

::v-deep .el-tabs__item.is-active {
    color: #3399ff;
}

::v-deep .el-tree-node__content {
    height: 30px;
}

::v-deep .custom-node-text {
    font-size: 14px;
    color: #303133;
    margin-left: 5px;
}

::v-deep .el-tree--highlight-current
    .el-tree-node.is-current
    > .el-tree-node__content {
    background: #d9ecff;
    border-radius: 8px 8px 8px 8px;
}

::v-deep .el-tree {
    height: calc(100% - 100px);
    overflow-y: auto;
    overflow-x: hidden;
}

::v-deep .el-tree::-webkit-scrollbar {
    width: 0 !important;
}
::v-deep .el-tree::-webkit-scrollbar-thumb {
    border-radius: 8px;
    background: rgba(0, 0, 0, 0.1) !important;
}
::v-deep .el-tree-node:focus > .el-tree-node__content {
    background-color: transparent;
}
::v-deep .el-input__inner {
    font-size: 14px;
}
</style>
